UpdateLayersPostClientSet

Struct UpdateLayersPostClientSet 

pub struct UpdateLayersPostClientSet;
When layers are cleared and messages from this tick are lost. Systems that read layer messages should run before this.